@@ -114,6 +114,7 @@ D1_D2_SETUP_ARGS = {
     "install_requires": ("metadata", "requires_dist"),
     "setup_requires": ("metadata", "setup_requires_dist"),
     "python_requires": ("metadata",),
+    "requires_python": ("metadata", "python_requires"),
     "provides": ("metadata", "provides_dist"),  # **
     "provides_extras": ("metadata",),
     "obsoletes": ("metadata", "obsoletes_dist"),  # **
@@ -127,7 +128,6 @@ D1_D2_SETUP_ARGS = {
     "cmdclass": ("global", "commands"),
     # Not supported in distutils2, but provided for
     # backwards compatibility with setuptools
-    "use_2to3": ("backwards_compat", "use_2to3"),
     "zip_safe": ("backwards_compat", "zip_safe"),
     "tests_require": ("backwards_compat", "tests_require"),
     "dependency_links": ("backwards_compat",),
@@ -157,7 +157,7 @@ MULTI_FIELDS = ("classifiers",
 MAP_FIELDS = ("project_urls",)
 
 # setup() arguments that contain boolean values
-BOOL_FIELDS = ("use_2to3", "zip_safe", "include_package_data")
+BOOL_FIELDS = ("zip_safe", "include_package_data")
 
 CSV_FIELDS = ()
 
@@ -548,7 +548,7 @@ def get_extension_modules(config):
         else:
             # Backwards compatibility for old syntax; don't use this though
             labels = section.split('=', 1)
-        labels = [l.strip() for l in labels]
+        labels = [label.strip() for label in labels]
         if (len(labels) == 2) and (labels[0] == 'extension'):
             ext_args = {}
             for field in EXTENSION_FIELDS:
